@@ -45,6 +45,11 @@ setMethodS3("getPlatform", "AromaMicroarrayDataSet", function(this, ...) {
 })
 
 
+setMethodS3("getDefaultFullName", "AromaMicroarrayDataSet", function(this, ...) {
+  NextMethod("getDefaultFullName", this, parent=1, ...);
+})
+
+
 setMethodS3("getChipType", "AromaMicroarrayDataSet", function(this, ...) {
   file <- getFile(this, 1);
   getChipType(file, ...);
@@ -59,6 +64,9 @@ setMethodS3("nbrOfArrays", "AromaMicroarrayDataSet", function(this, ...) {
 
 ############################################################################
 # HISTORY:
+# 2010-01-02
+# o Added getDefaultFullName() for AromaMicroarrayDataSet to override
+#   the new default of GenericDataFileSet in R.filesets v0.7.0.
 # 2009-02-13
 # o Now getChipType() passes on '...'.
 # 2008-05-23
